==> 1.0.0.tar.gz: lib/src/OAuthClient.dart <==
import 'dart:convert';

import 'package:braspag_oauth_dart/braspag_oauth_dart.dart';
import 'package:braspag_oauth_dart/src/BraspagOAuth.dart';
import 'package:braspag_oauth_dart/src/OAuthEnviroment.dart';
import 'package:braspag_oauth_dart/src/OAuthError.dart';
import 'package:dio/dio.dart';

class OAuthClient {
  Dio dio;
  OAuthClient(this.dio);

  Future<BraspagOAuth> getAccessToken(
      {String clientId,
      String clientSecret,
      OAuthEnviroment enviroment}) async {
    try {
      String basicAuth =
          'Basic ' + base64Encode(utf8.encode('$clientId:$clientSecret'));

      Map<String, String> body = {'grant_type': 'client_credentials'};

      dio.options
        ..baseUrl = baseUrl(enviroment)
        ..headers["content-type"] = "application/x-www-form-urlencoded"
        ..headers["authorization"] = basicAuth;

      var response = await dio.post("oauth2/token", data: body);

      return BraspagOAuth.fromJson(response.data);
    } on DioError catch (e) {
      _getErrorDio(e);
    } catch (e) {
      throw OAuthException(
          OAuthError(error: "unknown", errorDescription: "unknown"),
          "Falha ao tentar obter credenciais");
    }
    return null;
  }
}

String baseUrl(OAuthEnviroment enviroment) {
  return enviroment == OAuthEnviroment.PRODUCAO
      ? "https://auth.braspag.com.br/"
      : "https://authsandbox.braspag.com.br/";
}

_getErrorDio(DioError e) {
  if (e?.response != null) {
    Map<String, dynamic> map = e.response.data;
    OAuthError errorsOAuth = OAuthError.fromJson(map);

    throw OAuthException(errorsOAuth, e.message);
  } else {
    throw OAuthException(
        OAuthError(error: "unknown", errorDescription: "unknown"), e.message);
  }
}

==> 1.1.1.tar.gz: lib/src/OAuthClient.dart <==
import 'dart:convert';

import 'package:braspag_oauth_dart/oauth.dart';
import 'package:braspag_oauth_dart/src/OAuthError.dart';
import 'package:dio/dio.dart';

class OAuthClient {
  Dio dio;
  OAuthClient(this.dio);

  Future<BraspagOAuth> getAccessToken(
      {String clientId,
      String clientSecret,
      OAuthEnvironment environment}) async {
    try {
      String basicAuth =
          'Basic ' + base64Encode(utf8.encode('$clientId:$clientSecret'));

      Map<String, String> body = {'grant_type': 'client_credentials'};

      dio.options
        ..baseUrl = baseUrl(environment)
        ..headers["content-type"] = "application/x-www-form-urlencoded"
        ..headers["authorization"] = basicAuth;

      var response = await dio.post("oauth2/token", data: body);

      return BraspagOAuth.fromJson(response.data);
    } on DioError catch (e) {
      _getErrorDio(e);
    } catch (e) {
      throw ErrorResponseOAuth(
          code: "Unknown Error", message: "Falha ao tentar obter credenciais");
    }
    return null;
  }
}

String baseUrl(OAuthEnvironment enviroment) {
  return enviroment == OAuthEnvironment.PRODUCTION
      ? "https://auth.braspag.com.br/"
      : "https://authsandbox.braspag.com.br/";
}

_getErrorDio(DioError e) {
  if (e?.response != null) {
    Map<String, dynamic> map = e.response.data;
    OAuthError errorsOAuth = OAuthError.fromJson(map);

    throw ErrorResponseOAuth(
        code: "${e.response.statusCode}",
        message: errorsOAuth.errorDescription);
  } else {
    throw ErrorResponseOAuth(code: e.message, message: "Unknown Error");
  }
}
